@@ -16,3 +16,6 @@ with_seed <- function(seed, code) {
   }
   eval.parent(code)
 }
+
+# Copy from non exported arkhe
+catch_conditions <- arkhe:::catch_conditions
